@@ -9,14 +9,15 @@ Usage::
     data: AssetDestinationEntryTypeDef = {...}
     ```
 """
-from datetime import datetime
 import sys
+from datetime import datetime
 from typing import Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -204,9 +205,19 @@ class ExportAssetsToS3ResponseDetailsTypeDef(
     pass
 
 
-ExportServerSideEncryptionTypeDef = TypedDict(
-    "ExportServerSideEncryptionTypeDef", {"KmsKeyArn": str, "Type": Literal["aws:kms", "AES256"]}
+_RequiredExportServerSideEncryptionTypeDef = TypedDict(
+    "_RequiredExportServerSideEncryptionTypeDef", {"Type": Literal["aws:kms", "AES256"]}
 )
+_OptionalExportServerSideEncryptionTypeDef = TypedDict(
+    "_OptionalExportServerSideEncryptionTypeDef", {"KmsKeyArn": str}, total=False
+)
+
+
+class ExportServerSideEncryptionTypeDef(
+    _RequiredExportServerSideEncryptionTypeDef, _OptionalExportServerSideEncryptionTypeDef
+):
+    pass
+
 
 ImportAssetFromSignedUrlJobErrorDetailsTypeDef = TypedDict(
     "ImportAssetFromSignedUrlJobErrorDetailsTypeDef", {"AssetName": str}
